pub trait MetadataExt: Sealed {
// Required methods
fn change_time(self, time: i64) -> Self;
fn last_access_time(self, time: i64) -> Self;
fn last_write_time(self, time: i64) -> Self;
fn creation_time(self, time: i64) -> Self;
}Required Methods
Sourcefn change_time(self, time: i64) -> Self
fn change_time(self, time: i64) -> Self
The time the file was changed in FILETIME format.
Sourcefn last_access_time(self, time: i64) -> Self
fn last_access_time(self, time: i64) -> Self
The time the file was last accessed in FILETIME format.
Sourcefn last_write_time(self, time: i64) -> Self
fn last_write_time(self, time: i64) -> Self
The time the file was last written to in FILETIME format.
Sourcefn creation_time(self, time: i64) -> Self
fn creation_time(self, time: i64) -> Self
The time the file was created in FILETIME format.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".